% Script: PlotHazCurve.m
% Plot Hazard Curve from EFEHR portal with Quantiles
%
% Copyright (C) by J. Woessner
% 12.08.2013
% j.woessner@sed.ethz.ch
%
%
%% Licence
% SHARE data and products are released under the Creative Commons 
% Attribution-ShareAlike 3.0 Unported (CC BY-SA 3.0) licence.
%  
% For all SHARE datasets the following notice applies and/or is included within the files:
%  
% Copyright ? 2013, ETH Zurich on behalf of the EU-FP7 Consortium of SHARE
% 
% You may use this work under the terms of the CC BY-SA 3.0 (unported) 
% [http://creativecommons.org/licenses/by-sa/3.0/]
% 
% THE WORK IS PROTECTED BY COPYRIGHT AND/OR OTHER APPLICABLE LAW. INSOFAR 
% AS THIS WORK IS PROTECTED BY LAWS THAT NEIGHBOUR OR ARE SIMILARLY RELATED
% TO COPYRIGHT, SUCH AS DATABASE RIGHTS AS INTRODUCED IN EUROPE BY THE  
% DIRECTIVE 96/9/EC, YOU ALSO MAY USE THIS WORK UNDER THE TERMS OF 
% CC-BY-SA 3.0 (unported).
% 
% ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR 
% DIRECTLY ALLOWED BY THE APPLICABLE LAW IS PROHIBITED.
% 
% If you alter, transform, or build upon this work, you may distribute the 
% resulting work only under the same or similar license to this one. 
% 
% If you have any questions, or if you wish to seek permission to use this 
% data beyond what is offered by CC BY-SA 3.0 (unported), please contact 
% representatives of the EU-FP7 SHARE consortium at: 
% 
%  
% ETH Zurich / Swiss Seismological Service
% Sonneggstrasse 5
% CH-8092 Zurich, Switzerland
% email: share@sed.ethz.ch
% Tel.: +41-44-633-2179

%% Set Path
sPath=pwd;
addpath(genpath(sPath))

%% Define coordinate and IMT --- Only change this part
mXY = [7.3821339 47.5; 13.3821339 42.3; 6.8821339 50.9; 27.9821339 36.2; 28.9821339 41; 22.7821339 40.8; -9.2178661 38.7; 5.2821339 60.3];
sName = {'Basel'; 'L''Aquila'; 'Cologne'; 'Rhodes'; 'Istanbul'; 'Thessaloniki'; 'Lisbon'; 'Bergen'}

for n=1:length(mXY(:,1))
    fLon = mXY(n,1);
    fLat=mXY(n,2);
    sCity = char(sName(n));
    sIMT='PGA';
    
    
    % Get data from database
    [vIMT, vPoE5,sLoc] = GetEfehrHazCurve(fLon,fLat,sIMT,'rock','ordinal',0.05);
    [vIMT, vPoE15,sLoc] = GetEfehrHazCurve(fLon,fLat,sIMT,'rock','ordinal',0.15);
    [vIMT, vPoEMean,sLoc] = GetEfehrHazCurve(fLon,fLat,sIMT,'rock','arithmetic',0.5);
    [vIMT, vPoE85,sLoc] = GetEfehrHazCurve(fLon,fLat,sIMT,'rock','ordinal',0.85);
    [vIMT, vPoE95,sLoc] = GetEfehrHazCurve(fLon,fLat,sIMT,'rock','ordinal',0.95);
    
    % Prepare plot
    vIMT = str2num(vIMT);
    vIMT = vIMT';
    vPoE5=str2num(vPoE5)';
    vPoE15=str2num(vPoE15)';
    vPoEMean=str2num(vPoEMean)';
    vPoE85=str2num(vPoE85)';
    vPoE95=str2num(vPoE95)';
    vLoc = str2num(sLoc);
    
    % Plot
    figure
    loglog(vIMT,vPoE15,'Linestyle','-.','Linewidth',1.5,'Color',[0. 0.8 0])
    hold on
    loglog(vIMT,vPoE5,'Linestyle','--','Linewidth',1.5,'Color',[0.8 0 0])
    loglog(vIMT,vPoEMean,'Linewidth',2,'Marker','o','Markersize',5,'Color',[0 0 0],'MarkerFaceColor',[0.5 0.5 0.5])
    loglog(vIMT,vPoE85,'Linestyle','-.','Linewidth',1.5,'Color',[0. 0.8 0])
    loglog(vIMT,vPoE95,'Linestyle','--','Linewidth',1.5,'Color',[0.8 0 0])
    legend('5% Quantile','15% Quantile','Mean','85% Quantile','95% Quantile','Location','SouthWest')
    xlabel('Peak Ground Acceleration / [g]','Fontsize',12,'Fontweight','bold')
    ylabel('Probability of Exceedance in 50y','Fontsize',12,'Fontweight','bold')
    sTitle = [sCity ': Lon=' num2str(roundn(vLoc(1,1),-2)) ', Lat=' num2str(roundn(vLoc(1,2),-2)) ];
    title(sTitle,'Fontsize',10,'Fontweight','bold')
    ylim([0.005 1])
    xlim([0.0005 3])
    grid on
    box on
    set(gca,'XTickLabel',[0.001 0.01 0.1 1])
    set(gca,'YTickLabel',[0.01 0.1 1])
    
    % Add lines for 2% and 10% POE
    % 2% in 50y
    loglog([0.0005 3],[0.02 0.02],'-.','Linewidth',1.5,'Color',[0.5 0.5 0.5])
    text(0.001,0.022,'2% PoE in 50y','Fontsize',10,'Fontweight','bold','Color',[0.5 0.5 0.5])
    % 10% in 50y
    loglog([0.0005 3],[0.1 0.1],'-.','Linewidth',1.5,'Color',[0.5 0.5 0.5])
    text(0.001,0.11,'10% PoE in 50y','Fontsize',10,'Fontweight','bold','Color',[0.5 0.5 0.5])

    % Print
    sString = [sCity '_HazardCurve_' sIMT '_' num2str(fLon) '_' num2str(fLat) '.eps'];
    print('-depsc',sString)
    
end